@@ -4,7 +4,7 @@ from __future__ import division
 
 from ..adaptive import adaptive_comfort_ashrae55, adaptive_comfort_en15251, \
     adaptive_comfort_conditioned_function, cooling_effect_ashrae55, \
-    cooling_effect_en15251, t_operative, \
+    cooling_effect_en16798, cooling_effect_en15251, t_operative, \
     weighted_running_mean_hourly, weighted_running_mean_daily
 from ..parameter.adaptive import AdaptiveParameter
 from .base import ComfortCollection
@@ -76,7 +76,7 @@ class Adaptive(ComfortCollection):
                  '_cooling_effect_coll')
 
     def __init__(self, outdoor_temperature, operative_temperature, air_speed=None,
-                 comfort_parameter=None):
+                 comfort_parameter=None): 
         """Initialize an Adaptive comfort object from DataCollections of inputs.
         """
         # set up the object using operative temperature as a base
@@ -133,7 +133,7 @@ class Adaptive(ComfortCollection):
         return cls(outdoor_temperature, to, air_speed, comfort_parameter)
 
     def _calculate_adaptive(self):
-        """Compute Adaptive comfort for each step of the Data Collection."""
+        """Compute Adaptive comfort for each step of the Data Collection.""" 
         # empty properties to be calculated
         self._neutral_temperature = []
         self._degrees_from_neutral = []
@@ -145,21 +145,23 @@ class Adaptive(ComfortCollection):
         if self._comfort_par.conditioning != 0:
             comf_funct = adaptive_comfort_conditioned_function(
                 self._comfort_par.conditioning, self._comfort_par.standard)
-        elif self._comfort_par.ashrae55_or_en15251 is True:
+        elif self._comfort_par.ashrae_or_en:
             comf_funct = adaptive_comfort_ashrae55
         else:
             comf_funct = adaptive_comfort_en15251
 
         # determine the cooling effect function to use
-        if self._comfort_par.discrete_or_continuous_air_speed is True:
+        if not self._comfort_par.discrete_or_continuous_air_speed:
+            cooling_funct = cooling_effect_en15251
+        elif self._comfort_par.ashrae_or_en:
             cooling_funct = cooling_effect_ashrae55
         else:
-            cooling_funct = cooling_effect_en15251
+            cooling_funct = cooling_effect_en16798
 
         # perform the Adaptive calculation
         for tp, to, vel in zip(self._prevail_temp, self._op_temp, self._air_speed):
             result = comf_funct(tp, to)
-            ce = cooling_funct(vel, to)
+            ce = cooling_funct(vel, to, tp)
             comf = self._comfort_par.is_comfortable(result, ce)
             if comf == 0:
                 condit = 1 if result['deg_comf'] > 0 else -1
@@ -242,7 +244,7 @@ class Adaptive(ComfortCollection):
 
     @property
     def percent_comfortable(self):
-        """The percent of time comfortabe given by the assigned comfort_parameter."""
+        """The percent of time comfortable given by the assigned comfort_parameter."""
         return (sum(self._is_comfortable) / self._calc_length) * 100
 
     @property
